function [yhistory] = eulerint(yinit,deltat,timesteps)
%[yhistory] = eulerint(yinit,deltat,timesteps)
%
%EULER
%
% This function performs a simple first order euler simulation of a
% differential equation
%
% yinit      is the starting point (should be a column vector or a scalar)
% deltat     is the timestep
% timesteps  is the number of timesteps to simulate
%
% yhistory   is the output of the gradient descent; 
%            xhistory(timesteps) should hold the point to which the
%            descent converged
  
ydimensions = length(yinit);
yhistory = zeros(ydimensions,timesteps);
yhistory(:,1) = yinit;

%?
%?
%?
%?

 






